module Mod where
import A
h :: Int
h = g
